@@ -2,6 +2,7 @@ from functools import partial
 import importlib
 import inspect
 import logging
+from unicodedata import east_asian_width
 
 
 logger = logging.getLogger(__name__)
@@ -55,4 +56,16 @@ def make_partial(func, **kwargs):
 
 
 def is_available(package: str):
-    return importlib.util.find_spec(package) is not None
\ No newline at end of file
+    return importlib.util.find_spec(package) is not None
+
+
+def width(text: str):
+    if not isinstance(text, str):
+        text = str(text)
+    l = 0
+    for s in text:
+        if east_asian_width(s) in ['F', 'W']:
+            l += 2
+        else:
+            l += 1
+    return l
\ No newline at end of file
